@@ -392,7 +392,7 @@ from ae.core import DEBUG_LEVELS, registered_app_names
 from ae.console import ConsoleApp                                                                       # type: ignore
 
 
-__version__ = '0.1.72'
+__version__ = '0.1.74'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -580,6 +580,18 @@ def flow_popup_class_name(flow_id: str) -> str:
     return flow_class_name(flow_id, 'Popup')
 
 
+def font_min_max_size_from_win(win_width: float, win_height: float) -> Tuple[float, float]:
+    """ calculate optimal range of font size depending on the window/screen resolution.
+
+    :param win_width:       window/screen width in pixels.
+    :param win_height:      window/screen height in pixels.
+    :return:                minimum and maximum font size in pixels.
+    """
+    min_len = min(win_width, win_height)
+    return (min(max(MIN_FONT_SIZE, round(min_len / 48.9)), MAX_FONT_SIZE),
+            min(max(MIN_FONT_SIZE, round(min_len / 24.6)), MAX_FONT_SIZE))
+
+
 def id_of_flow(action: str, obj: str = "", key: str = "") -> str:
     """ create flow id string.
 
@@ -770,7 +782,7 @@ class MainAppBase(ConsoleApp, ABC):
 
         self.change_observable(app_state_name, state_value, is_app_state=True)
 
-        if old_name or old_name == UNSET:
+        if old_name or old_name is UNSET:
             self.set_var(app_state_name, state_value, section=APP_STATE_SECTION_NAME, old_name=old_name or "")
 
         if send_event:
@@ -875,7 +887,8 @@ class MainAppBase(ConsoleApp, ABC):
         popups_to_close = event_kwargs.get('popups_to_close', ())
         for widget in reversed(popups_to_close):
             widget.close()
-            widget.attach_to = None     # mainly for DropDown widgets to prevent weakref-error/-exception
+            if hasattr(widget, 'attach_to'):
+                widget.attach_to = None     # mainly for DropDown widgets to prevent weakref-error/-exception
 
         if action not in ACTIONS_REDUCING_FLOW_PATH or not has_flow_focus:
             flow_id = event_kwargs.get('flow_id', flow_id)  # update flow_id from event_kwargs
@@ -915,7 +928,7 @@ class MainAppBase(ConsoleApp, ABC):
 
     @staticmethod
     def dpi_factor() -> float:
-        """ dpi scaling factor - overwrite if the used GUI framework supports dpi scaling. """
+        """ dpi scaling factor - override if the used GUI framework supports dpi scaling. """
         return 1.0
 
     def close_popups(self):
@@ -1107,15 +1120,7 @@ class MainAppBase(ConsoleApp, ABC):
 
     def on_app_build(self):
         """ default/fallback flow change confirmation event handler. """
-        self.vpo("MainAppBase.on_app_build default/fallback event handler called - loading app resources")
-
-        self.load_images()
-
-        self.load_sounds()
-
-        register_translations_path()
-        register_translations_path("{ado}")
-        self.load_translations(self.lang_code)
+        self.vpo("MainAppBase.on_app_build default/fallback event handler called")
 
     def on_app_exit(self):
         """ default/fallback flow change confirmation event handler. """
@@ -1134,8 +1139,16 @@ class MainAppBase(ConsoleApp, ABC):
         self.vpo("MainAppBase.on_app_run default/fallback event handler called")
 
     def on_app_start(self):
-        """ default/fallback flow change confirmation event handler. """
-        self.vpo("MainAppBase.on_app_start default/fallback event handler called")
+        """ default/fallback flow change confirmation event handler, used to load app resources. """
+        self.vpo("MainAppBase.on_app_start default/fallback event handler called - loading app resources")
+
+        self.load_images()
+
+        self.load_sounds()
+
+        register_translations_path()
+        register_translations_path("{ado}")
+        self.load_translations(self.lang_code)
 
     def on_app_stop(self):
         """ default/fallback flow change confirmation event handler. """
@@ -1242,18 +1255,21 @@ class MainAppBase(ConsoleApp, ABC):
         self.po(f"MainAppBase.play_vibrate {pattern}")
 
     def open_popup(self, popup_class: Type, **popup_kwargs) -> Any:
-        """ open Popup or DropDown by calling `show` method of passed instance.
-
-        Overwrite this method if framework is using different method to open popup window or if
-        a widget in the Popup/DropDown need to get the input focus.
+        """ open Popup/DropDown, calling the `open`/`show` method of the instance created from the passed popup class.
 
         :param popup_class:     class of the Popup/DropDown widget/window.
         :param popup_kwargs:    args for to instantiate and show/open the popup.
         :return:                created and displayed/opened popup class instance.
+
+        .. hint::
+            Overwrite this method if framework is using different method to open popup window or if
+            a widget in the Popup/DropDown need to get the input focus.
         """
         self.dpo(f"MainAppBase.open_popup {popup_class} {popup_kwargs}")
         popup_instance = popup_class(**popup_kwargs)
-        popup_instance.open()
+        open_method = getattr(popup_instance, 'open', getattr(popup_instance, 'show', None))
+        if open_method:
+            open_method()
         return popup_instance
 
     def popups_opened(self, classes: Tuple = ()) -> List:
@@ -1346,9 +1362,13 @@ class MainAppBase(ConsoleApp, ABC):
         self.vpo(f"MainAppBase.setup_app_states {app_states}")
 
         font_size = app_states.get('font_size', 0)
-        if not MIN_FONT_SIZE <= font_size <= MAX_FONT_SIZE:
-            if font_size < 0:
-                font_size = self.dpi_factor() * -font_size      # adopt device scaling on very first app start
+        win_width, win_height = app_states.get('win_rectangle', (0, 0, 1920, 1080))[2:]
+        if not MIN_FONT_SIZE <= font_size <= MAX_FONT_SIZE:   # adopt device scaling on very first app start
+            if font_size == -1.0:
+                min_f, max_f = font_min_max_size_from_win(win_width, win_height)
+                font_size = min_f + (max_f - min_f) / 3.0
+            elif font_size < 0.0:
+                font_size = self.dpi_factor() * -font_size
             app_states['font_size'] = min(max(MIN_FONT_SIZE, font_size), MAX_FONT_SIZE)
 
         for key, val in app_states.items():
@@ -1445,13 +1465,10 @@ class MainAppBase(ConsoleApp, ABC):
         """
         app = self.framework_app
         win_width, win_height = win_pos_size[2:]
-
         app.landscape = win_width >= win_height                 # update landscape flag
 
-        min_len = min(win_width, win_height)
         font_size = self.font_size
-        max_f = min(round(min_len / 24.6), MAX_FONT_SIZE)
-        min_f = max(round(min_len / 48.9), MIN_FONT_SIZE)
+        min_f, max_f = font_min_max_size_from_win(win_width, win_height)
         if not min_f <= font_size <= max_f:
             self.change_app_state('font_size', min(max(min_f, font_size), max_f))
         app.max_font_size = max_f                               # update dynamic min/max font size
